@@ -49,16 +49,6 @@ class DataTypes:
             }
         }, ptyp2)
 
-    @staticmethod
-    def decimal(ptyp2: dict or None = None) -> dict:
-        return DataTypes.type({
-            'type': 'float',
-            'message': {
-                lang.EN: "{name} must be a valid decimal number",
-                lang.ES: "{name} debe ser un número decimal válido",
-            }
-        }, ptyp2)
-
     @staticmethod
     def hexadecimal(ptyp2: dict or None = None) -> dict:
         return DataTypes.type({
